enum EditTupleUsage {
NoIndex(TextRange),
ReplaceExpr(Expr, Expr),
}Variants
NoIndex(TextRange)
no index access -> make invalid -> requires handling by user -> put usage in block comment
Note: For macro invocations this might result in still valid code:
When a macro accepts the tuple as argument, as well as no arguments at all,
uncommenting the tuple still leaves the macro call working (see tests::in_macro_call::empty_macro).
But this is an unlikely case. Usually the resulting macro call will become erroneous.
ReplaceExpr(Expr, Expr)
Implementations
Sourceimpl EditTupleUsage
impl EditTupleUsage
fn apply( self, ctx: &AssistContext<'_, '_>, edit: &mut SourceChangeBuilder, syntax_editor: &SyntaxEditor, )